Package: nparLD
Version: 2.2
Date: 2022-08-06
Title: Nonparametric Analysis of Longitudinal Data in Factorial
        Experiments
Author: Kimihiro Noguchi <noguchk@wwu.edu>, Mahbub Latif
        <mlatif@isrt.ac.bd>, Karthinathan Thangavelu,
        Frank Konietschke <frank.konietschke@charite.de>, Yulia R. Gel
        <yxg142030@utdallas.edu>, Edgar Brunner
        <ebrunne1@gwdg.de>
Maintainer: Frank Konietschke <frank.konietschke@charite.de>
Depends: R (>= 2.6.0), MASS
License: GPL (>= 2)
Description: Performs nonparametric
        analysis of longitudinal data in factorial experiments.
        Longitudinal data are those which are collected from the same
        subjects over time, and they frequently arise in biological
        sciences. Nonparametric methods do not require distributional
        assumptions, and are applicable to a variety of data types
        (continuous, discrete, purely ordinal, and dichotomous).  Such
        methods are also robust with respect to outliers and for small
        sample sizes.
NeedsCompilation: no
Packaged: 2022-08-06 14:39:07 UTC; Matthias
Repository: CRAN
Date/Publication: 2022-08-07 00:00:02 UTC
Built: R 4.6.0; ; 2026-04-26 23:09:00 UTC; unix
