# Generated by roxygen2: do not edit by hand

S3method(plot,nparld_fit)
S3method(plot,nparld_mctp)
S3method(print,nparld_covarianceinfo)
S3method(print,nparld_factorinfo)
S3method(print,nparld_fit)
S3method(print,nparld_mctp)
S3method(print,summary.nparld_fit)
S3method(summary,nparld_fit)
export(nparLD)
importFrom(graphics,abline)
importFrom(graphics,axis)
importFrom(graphics,points)
importFrom(graphics,segments)
importFrom(rlang,.data)
importFrom(stats,aggregate)
importFrom(stats,as.formula)
importFrom(stats,ave)
importFrom(stats,cov2cor)
importFrom(stats,model.frame)
importFrom(stats,na.pass)
importFrom(stats,pchisq)
importFrom(stats,pf)
importFrom(stats,pt)
importFrom(stats,qnorm)
importFrom(stats,qt)
importFrom(stats,quantile)
importFrom(stats,rbinom)
importFrom(stats,reshape)
importFrom(stats,sd)
importFrom(stats,setNames)
importFrom(stats,terms)
importFrom(stats,var)
