% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{panic}
\alias{panic}
\title{Panic Disorder Study I}
\format{
A data frame with variables:
\describe{
\item{resp}{Clinical Global Impression score.}
\item{time}{Visit or week of assessment.}
\item{subject}{Patient identifier.}
}
}
\usage{
panic
}
\description{
Clinical Global Impression scores from patients with panic disorder and
agoraphobia. The data illustrate a one-factor longitudinal design with
ordinal responses.
}
\examples{
data(panic)

\dontrun{
fit <- nparLD(resp ~ time,
              data = panic,
              subject = "subject",
              hypothesis = "H0F", contrast =list("time", "Dunnett"))
fit
}

\dontrun{
fit <- nparLD(resp ~ time,
              data = panic,
              subject = "subject",
              hypothesis = "H0p",
              contrast = list("time", "Dunnett"))
fit
plot(fit)
plot(fit$MCTP)
}

}
\keyword{datasets}
