% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{plasma}
\alias{plasma}
\title{Plasma-renin Activity Study}
\format{
A data frame with variables:
\describe{
\item{resp}{Plasma-renin activity measurement.}
\item{time}{Measurement time.}
\item{group}{Drug group.}
\item{subject}{Subject identifier.}
}
}
\usage{
plasma
}
\description{
Plasma-renin activity measurements from a randomized study of healthy
non-smokers. The data illustrate a factorial longitudinal design with one
whole-plot factor and one repeated-measures factor.
}
\examples{
data(plasma)

\dontrun{
fit <- nparLD(resp ~ group * time,
              data = plasma,
              subject = "subject",
              hypothesis = "H0F", effect="weighted")
fit
}

\dontrun{
fit <- nparLD(resp ~ group * time,
              data = plasma,
              subject = "subject",
              hypothesis = "H0p",
              contrast = list("group", "Tukey"))
fit
plot(fit)
plot(fit$MCTP)
}

}
\keyword{datasets}
