% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{dental}
\alias{dental}
\title{Dental Growth Study}
\format{
A data frame with variables:
\describe{
\item{resp}{Distance measurement in millimeters.}
\item{time}{Age at measurement.}
\item{subject}{Subject identifier.}
}
}
\usage{
dental
}
\description{
Measurements of distances between the center of the pituitary and the
pterygomaxillary fissure in boys. The data illustrate a one-factor
longitudinal design.
}
\examples{
data(dental)

dental$time <- factor(dental$time)

\dontrun{
fit <- nparLD(resp ~ time,
              data = dental,
              subject = "subject",
              hypothesis = "H0F")
fit
}

\dontrun{
fit <- nparLD(resp ~ time,
              data = dental,
              subject = "subject",
              hypothesis = "H0p",
              contrast = list("time", "Tukey"))
fit
plot(fit)
plot(fit$MCTP)
}

}
\keyword{datasets}
