% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{panic2}
\alias{panic2}
\title{Panic Disorder Study II}
\format{
A data frame with variables:
\describe{
\item{resp}{Panic and agoraphobia score.}
\item{time}{Visit or week of assessment.}
\item{group}{Agoraphobia group.}
\item{subject}{Patient identifier.}
}
}
\usage{
panic2
}
\description{
Panic and agoraphobia scores from patients with panic disorder, with or
without agoraphobia. The data illustrate a factorial longitudinal design with
one whole-plot factor and one repeated-measures factor.
}
\examples{
data(panic2)

\dontrun{
fit <- nparLD(resp ~ group * time,
              data = panic2,
              subject = "subject",
              hypothesis = "H0F", effect="unweighted")
fit
}

\dontrun{
fit <- nparLD(resp ~ group * time,
              data = panic2,
              subject = "subject",
              hypothesis = "H0p",
              contrast = list("group:time"),
              Factor.Information = TRUE,
              covariance=TRUE)
fit
plot(fit)
plot(fit$MCTP)
}

}
\keyword{datasets}
