% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{amylase}
\alias{amylase}
\title{Alpha-amylase Saliva Study}
\format{
A data frame with variables:
\describe{
\item{resp}{Alpha-amylase measurement.}
\item{time1}{First repeated-measures factor.}
\item{time2}{Second repeated-measures factor.}
\item{subject}{Subject identifier.}
}
}
\usage{
amylase
}
\description{
Measurements of alpha-amylase levels in saliva from healthy volunteers.
The study illustrates a two-factor longitudinal design with two repeated
measures factors.
}
\examples{
data(amylase)

fit <- nparLD(resp ~ time1 * time2,
              data = amylase,
              subject = "subject",
              effect = "weighted",
              hypothesis = "H0F")
fit

# Dunnett-type contrasts for the levels of time2
fit <- nparLD(resp ~ time1 * time2,
              data = amylase,
              subject = "subject",
              hypothesis = "H0p",
              contrast = list("time2", "Dunnett"),
              Factor.Information = TRUE)
fit
plot(fit)
plot(fit$MCTP)

}
\keyword{datasets}
