% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/Utility.R
\name{print.nparld_factorinfo}
\alias{print.nparld_factorinfo}
\title{Print nparLD factor information}
\usage{
\method{print}{nparld_factorinfo}(x, digits = 4, ...)
}
\arguments{
\item{x}{An object of class \code{"nparld_factorinfo"}.}

\item{digits}{Number of digits used for printing numerical results.}

\item{...}{Further arguments.}
}
\description{
Prints factor-specific relative effects, standard errors, and confidence
limits for the main effects and interactions of an \code{nparLD()} fit.
Factor information is returned when the model is fitted with
\code{Factor.Information = TRUE} and can also be displayed graphically with
\code{plot(fit, term = ...)}.
}
\details{
Factor information consists of term-specific relative effects, standard
errors, and confidence limits for main effects and interactions. These
summaries are returned when \code{Factor.Information = TRUE} and can be
visualized with \code{plot(fit, term = ...)}.
}
