% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{brdu}
\alias{brdu}
\title{BrdU incorporation in fibroblasts}
\format{
A data frame with 60 rows and 4 variables:
\describe{
\item{resp}{BrdU incorporation response.}
\item{dose}{Dose condition, with levels \code{0}, \code{0.1}, \code{1}, and \code{10}.}
\item{culture}{Culture identifier. This is the independent experimental unit.}
\item{replicate}{Replicate identifier within each culture-dose condition.}
}
}
\usage{
brdu
}
\description{
BrdU incorporation in fibroblast cultures measured under four dose
conditions. For each culture and dose condition, three replicate measurements
are available. The data set is provided in long format and can be used to
illustrate dependent replicate measurements in \code{nparLD()}.
}
\details{
The original variables were \code{CultureNo}, \code{Replic}, \code{Dose}, and \code{Brdu}.
In the package data set, the variables were renamed to \code{culture},
\code{replicate}, \code{dose}, and \code{resp} for consistency with the examples.
}
\examples{
\dontrun{
data(brdu)

fit <- nparLD(
  resp ~ dose,
  data = brdu,
  subject = "culture",
  replicate = "replicate",
  hypothesis = "H0p",
  cell.weights = "subjects"
)

fit
}

}
\keyword{datasets}
