% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/Utility.R
\name{print.nparld_covarianceinfo}
\alias{print.nparld_covarianceinfo}
\title{Print nparLD covariance matrix}
\usage{
\method{print}{nparld_covarianceinfo}(x, digits = 4, ...)
}
\arguments{
\item{x}{An object of class \code{"nparld_covarianceinfo"}.}

\item{digits}{Number of digits used for printing numerical results.}

\item{...}{Further arguments.}
}
\description{
Displays the estimated covariance matrix of the relative effect estimator.
}
\details{
The printed matrix is the estimated covariance matrix used for the selected
hypothesis. It is returned when \code{covariance = TRUE}.
}
