% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{edema}
\alias{edema}
\title{Postoperative Edema Study}
\format{
A data frame with variables:
\describe{
\item{resp}{Skin temperature measurement.}
\item{time1}{Hand factor.}
\item{time2}{Day factor.}
\item{group}{Treatment group.}
\item{subject}{Subject identifier.}
}
}
\usage{
edema
}
\description{
Skin-temperature measurements from patients after hand surgery. The study
compares treatment groups and includes two repeated-measures factors.
}
\examples{
data(edema)

\dontrun{
fit <- nparLD(resp ~ group * time1 * time2,
              data = edema,
              subject = "subject",
              hypothesis = "H0F")
fit
}

\dontrun{
fit <- nparLD(resp ~ group * time1 * time2,
              data = edema,
              subject = "subject",
              hypothesis = "H0p",
              contrast = list("group", "Tukey"),
              Factor.Information = TRUE)
fit
plot(fit)
plot(fit$MCTP)
}

}
\keyword{datasets}
