% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{respiration}
\alias{respiration}
\title{Respiratory Disorder Study}
\format{
A data frame with variables:
\describe{
\item{resp}{Ordinal health-status response.}
\item{time}{Visit number.}
\item{center}{Study center.}
\item{treatment}{Treatment group.}
\item{patient}{Patient identifier.}
}
}
\usage{
respiration
}
\description{
Ordinal health-status measurements from patients with a respiratory disorder.
The data include study center, treatment group, and repeated visits.
}
\examples{

\dontrun{
data(respiration)

fit <- nparLD(resp ~ center * treatment * time,
              data = respiration,
              subject = "patient",
              hypothesis = "H0F")
fit
}

\dontrun{
fit <- nparLD(resp ~ center * treatment * time,
              data = respiration,
              subject = "patient",
              hypothesis = "H0p",
              contrast = list("treatment", "Tukey"))
fit
plot(fit)
plot(fit$MCTP)
}

}
\keyword{datasets}
