% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{tree}
\alias{tree}
\title{Vitality of Treetops}
\format{
A data frame with variables:
\describe{
\item{resp}{Vitality score.}
\item{time}{Year or measurement occasion.}
\item{group}{Experimental area.}
\item{subject}{Tree identifier.}
}
}
\usage{
tree
}
\description{
Repeated vitality scores of treetops from three experimental areas. The data
illustrate an ordinal longitudinal response in several groups.
}
\examples{
data(tree)

\dontrun{
fit <- nparLD(resp ~ group * time,
              data = tree,
              subject = "subject",
              hypothesis = "H0F")
fit
}


\dontrun{
fit <- nparLD(resp ~ group * time,
              data = tree,
              subject = "subject",
              hypothesis = "H0p",
              contrast = list("group:time"))
fit
plot(fit)
plot(fit$MCTP)
}

}
\keyword{datasets}
