% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{shoulder}
\alias{shoulder}
\title{Shoulder Tip Pain Study}
\format{
A data frame with variables:
\describe{
\item{resp}{Shoulder pain score.}
\item{time}{Measurement occasion.}
\item{group1}{Treatment group.}
\item{group2}{Gender group.}
\item{subject}{Patient identifier.}
}
}
\usage{
shoulder
}
\description{
Shoulder pain scores from patients after laparoscopic abdominal surgery. The
study includes treatment group, gender group, and repeated pain measurements.
}
\examples{
data(shoulder)

\dontrun{
fit <- nparLD(resp ~ group1 * group2 * time,
              data = shoulder,
              subject = "subject",
              hypothesis = "H0F")
fit
}

\dontrun{
fit <- nparLD(resp ~ group1 * group2 * time,
              data = shoulder,
              subject = "subject",
              hypothesis = "H0p",
              contrast = list("group1:time"),
              Factor.Information=TRUE)
fit
plot(fit)
plot(fit$MCTP)
}

}
\keyword{datasets}
